==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Test/Gui/Resources/translations/Test_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>障害およびエラー</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>説明</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>開始（&amp;S）</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;About</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>閉じる (&amp;C)</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Idle</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>進捗状況</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>残り：</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>エラー:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>エラー:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>実行：</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>テスト</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Select test name:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>ヘルプ</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD ユニットテストについて</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Test/Gui/Resources/translations/Test_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>障害およびエラー</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>説明</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>開始（&amp;S）</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;About</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>待機中</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>進捗状況</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>残り：</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>エラー:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>エラー:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>実行：</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>テスト</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>テスト名を選択:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>ヘルプ</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD ユニットテストについて</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>呼び出し時にTestCase.Click 'start'を返す呼び出し可能なオブジェクトの名前を入力してください。入力するとそれに従って作成されたテストが実行されます。

ツリービューのエラーをダブルクリックするとスタックトレースを含むより詳細な情報が確認できます。</translation>
    </message>
  </context>
</TS>
